<?php

namespace Drupal\aichat;

use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Provides an interface for defining aichat entities.
 *
 * @ingroup aichat
 */
interface AIChatInterface extends ContentEntityInterface {
  
  /**
   * Gets a value from conversation data.
   *
   * @param string $key
   *   The key of the data to retrieve.
   *
   * @return mixed
   *   The data value for the requested key. NULL if the key does not exist.
   */
  public function getDataValue(string $key): mixed;

  /**
   * Gets a value from nested conversation data.
   *
   * @param string $key
   *   The key of the data to retrieve.
   * @param string $subkey
   *   The subkey of the data to retrieve.
   *
   * @return mixed
   *   The data subvalue for the requested key and subkey. NULL if the key or subkey does not exist.
   */
  public function getDataSubValue(string $key, string $subkey): mixed;

  /**
   * Sets a value into conversation data.
   *
   * @param string $key
   *   The key of the data to set.
   * @param mixed $value
   *   The value to be set.
   * @param bool $save
   *   If the setting of the value should run saveData() method
   */
  public function setDataValue(string $key, $value, $save = TRUE): void;

  /**
   * Sets a value into nested conversation data.
   *
   * @param string $key
   *   The key of the data to set.
   * @param string $subkey
   *   The subkey of the data to set.
   * @param mixed $value
   *   The value to be set.
   * @param bool $save
   *   If the setting of the value should run saveData() method
   */
  public function setDataSubValue(string $key, string $subkey, $value, bool $save = TRUE): void;

  /**
   * Set data field to entity.
   */
  public function saveData(): void;

}